@@ -6,6 +6,7 @@ use warnings;
 use Archive::Tar;
 use Clone qw(clone);
 use Data::Dumper;
+use FindBin ();
 use File::Basename;
 use File::Spec;
 use File::Temp;
@@ -147,10 +148,11 @@ my $dist_copyright = $license_obj->notice;
 if ( open my $fh, '>', 'corelist' ) {
     print $fh q~package Module::OTRS::CoreList;
 
+# ABSTRACT: what modules shipped with versions of OTRS (>= 2.3.x) 
+
 use strict;
 use warnings;
 
-# ABSTRACT: what modules shipped with versions of OTRS (>= 2.3.x)
 ~;
 
     print $fh "\n\n";
@@ -260,12 +262,15 @@ sub cpan_modules {
 }
 
 1;
+
+__END__
+
+=for Pod::Coverage modules shipped cpan_modules
+
 #;
 
-print $fh qq~
-
-=pod
-
+    open my $pod_fh, '>', $FindBin::Bin . '/../lib/Module/OTRS/CoreList.pod';
+print $pod_fh qq~
 =head1 NAME
 
 Module::OTRS::CoreList - what modules shipped with versions of OTRS (>= 2.3.x)
@@ -276,7 +281,7 @@ version $dist_version
 
 ~;
 
-print $fh q~=head1 SYNOPSIS
+print $pod_fh q~=head1 SYNOPSIS
 
  use Module::OTRS::CoreList;
 
@@ -301,7 +306,7 @@ print $fh q~=head1 SYNOPSIS
 
 ~;
 
-print $fh qq~
+print $pod_fh qq~
 =head1 AUTHOR
 
 $dist_author
